from wallger import helpers

options = {
    "monitor_long": helpers.get_config("monitor", "long"),
    "monitor_height": helpers.get_config("monitor", "height"),
    "provider": helpers.get_config("wallpaper", "provider"),
    "local": helpers.get_config("wallpaper", "local"),
    "topic": helpers.get_config("wallpaper", "topic"),
    "nfsw": helpers.get_config("wallpaper", "nfsw"),
    "save": helpers.get_config("misc", "save"),
    "system": helpers.get_config("misc", "system"),
}


def main():
    try:
        helpers.set_image(options)
    except Exception as exception:
        print(f"Oops!, {exception} ocurred.")



import json
from importlib import import_module
from os.path import expanduser

from wallger.providers.provider import Provider


def get_config_file():
    """get_config_file."""
    try:
        with open(expanduser("~/.config/wallger/config.json"), "r") as json_data:
            return json.load(json_data)
    except FileNotFoundError:
        print("No config.")


def get_config(secction: str, option: str):
    """get_config.

    :param secction:
    :type secction: str
    :param option:
    :type option: dict
    """
    json_data = get_config_file()
    try:
        return json_data[secction][option]
    except:
        return "none"


def generate_class(options: dict, url: str, filename: str):
    """generate_class.

    :param options:
    :type options: dict
    :param url:
    :type url: str
    :param filename:
    :type filename: str
    """
    return Provider(
        options["monitor_long"],
        options["monitor_height"],
        options["topic"],
        options["save"],
        url,
        filename,
        options["system"],
    )


def dynamic_import(module: str):
    """dynamic_import.

    :param module:
    :type module: str
    """
    try:
        return import_module(module)
    except ImportError as error:
        print(f"Oops {error} ocurred.")


def set_image(options: dict):
    """set_image.

    :param options:
    :type options: dict
    """
    provider = options["provider"]
    if provider == "wallhaven":
        from wallger.providers.wallhaven import run

        run(options)
    if provider == "unsplash":
        from wallger.providers.unsplash import run

        run(options)
    if provider == "local":
        from wallger.providers.local import run

        run(options)



from setuptools import setup
from wallger.version import __version__


setup(
    name="wallger",
    packages=["wallger"],
    version=__version__,
    license="MIT",
    description="Wallpaper changer for Linux, get images from Wallhaven, Unsplash and others!",
    author="Eliaz Bobadilla",
    url="https://github.com/UltiRequiem/wallger",
    keywords=["unsplash", "wallhaven", "feh", "wallpaper", "cli"],
    long_description=open("README.md").read(),
    long_description_content_type="text/markdown",
    entry_points={"console_scripts": ["wallger = wallger.run:main"]},
    install_requires=["requests==2.25.1"],
)
